@@ -15,4 +15,4 @@ def main(app, args):
 
 
 if __name__ == "__main__":
-    main(app, ())
+    main(app, ())  # noqa: F821
