@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 from euphorie.client.model import Session as EuphorieSession
+from euphorie.content.surveygroup import ISurveyGroup
 from osha.oira.statistics.model import get_postgres_url
 from osha.oira.statistics.utils import UpdateStatisticsDatabases
 from osha.oira.statistics.utils import update_tool_info
+from plone import api
 from Products.Five import BrowserView
-from zope import component
-from zope import schema
 
 import logging
 
@@ -31,20 +31,11 @@ class UpdateStatistics(BrowserView):
 class UpdateToolInfo(BrowserView):
     def __call__(self):
         log.info("Writing survey (tool) information to postgresql")
-        surveys = component.getUtility(
-            schema.interfaces.IVocabularyFactory, "osha.oira.toolversions"
-        )(self.context)
-
-        for survey_path in surveys:
-            survey = self.context["sectors"].unrestrictedTraverse(survey_path)
-            if not survey.portal_type == "euphorie.survey":
-                log.info(
-                    "Object is not a survey but inside "
-                    "surveygroup, skipping. %s" % "/".join(survey.getPhysicalPath())
-                )
-                continue
-
-            update_tool_info(survey)
+        catalog = api.portal.get_tool("portal_catalog")
+        brains = catalog(object_provides=ISurveyGroup.__identifier__)
+        for brain in brains:
+            surveygroup = brain.getObject()
+            update_tool_info(surveygroup)
 
         log.info("Done")
         return "Done"
